==> maleo_identity-0.0.15.tar.gz: maleo_identity-0.0.15/maleo_identity/models/transfers/parameters/client/user_organization.py <==
from __future__ import annotations
from maleo_foundation.models.transfers.parameters.client import BaseClientParametersTransfers
from maleo_identity.models.schemas.general.user_organization import MaleoIdentityUserOrganizationGeneralSchemas

class MaleoIdentityUserOrganizationClientParametersTransfers:
    class GetMultipleFromUser(
        MaleoIdentityUserOrganizationGeneralSchemas.Expand,
        MaleoIdentityUserOrganizationGeneralSchemas.OptionalListOfOrganizationId,
        MaleoIdentityUserOrganizationGeneralSchemas.UserId,
        BaseClientParametersTransfers.GetPaginatedMultiple
    ): pass

    class GetMultipleFromOrganization(
        MaleoIdentityUserOrganizationGeneralSchemas.Expand,
        MaleoIdentityUserOrganizationGeneralSchemas.OrganizationId,
        MaleoIdentityUserOrganizationGeneralSchemas.OptionalListOfUserId,
        BaseClientParametersTransfers.GetPaginatedMultiple
    ): pass
    
    class GetMultiple(
        MaleoIdentityUserOrganizationGeneralSchemas.Expand,
        MaleoIdentityUserOrganizationGeneralSchemas.OptionalListOfOrganizationId,
        MaleoIdentityUserOrganizationGeneralSchemas.OptionalListOfUserId,
        BaseClientParametersTransfers.GetPaginatedMultiple
    ): pass

    class GetMultipleFromUserQuery(
        MaleoIdentityUserOrganizationGeneralSchemas.Expand,
        MaleoIdentityUserOrganizationGeneralSchemas.OptionalListOfOrganizationId,
        BaseClientParametersTransfers.GetPaginatedMultipleQuery
    ): pass

    class GetMultipleFromOrganizationQuery(
        MaleoIdentityUserOrganizationGeneralSchemas.Expand,
        MaleoIdentityUserOrganizationGeneralSchemas.OptionalListOfUserId,
        BaseClientParametersTransfers.GetPaginatedMultipleQuery
    ): pass

    class GetMultipleQuery(
        MaleoIdentityUserOrganizationGeneralSchemas.Expand,
        MaleoIdentityUserOrganizationGeneralSchemas.OptionalListOfOrganizationId,
        MaleoIdentityUserOrganizationGeneralSchemas.OptionalListOfUserId,
        BaseClientParametersTransfers.GetPaginatedMultipleQuery
    ): pass

==> maleo_identity-0.0.30.tar.gz: maleo_identity-0.0.30/maleo_identity/models/transfers/parameters/client/user_organization.py <==
from __future__ import annotations
from maleo_foundation.models.transfers.parameters.client import BaseClientParametersTransfers
from maleo_identity.models.schemas.general.user_organization import MaleoIdentityUserOrganizationGeneralSchemas

class MaleoIdentityUserOrganizationClientParametersTransfers:
    class GetMultipleFromUser(
        MaleoIdentityUserOrganizationGeneralSchemas.Expand,
        BaseClientParametersTransfers.GetPaginatedMultiple,
        MaleoIdentityUserOrganizationGeneralSchemas.OptionalListOfOrganizationId,
        MaleoIdentityUserOrganizationGeneralSchemas.UserId
    ): pass

    class GetMultipleFromOrganization(
        MaleoIdentityUserOrganizationGeneralSchemas.Expand,
        BaseClientParametersTransfers.GetPaginatedMultiple,
        MaleoIdentityUserOrganizationGeneralSchemas.OrganizationId,
        MaleoIdentityUserOrganizationGeneralSchemas.OptionalListOfUserId
    ): pass
    
    class GetMultiple(
        MaleoIdentityUserOrganizationGeneralSchemas.Expand,
        BaseClientParametersTransfers.GetPaginatedMultiple,
        MaleoIdentityUserOrganizationGeneralSchemas.OptionalListOfOrganizationId,
        MaleoIdentityUserOrganizationGeneralSchemas.OptionalListOfUserId
    ): pass

    class GetMultipleFromUserQuery(
        MaleoIdentityUserOrganizationGeneralSchemas.Expand,
        BaseClientParametersTransfers.GetPaginatedMultipleQuery,
        MaleoIdentityUserOrganizationGeneralSchemas.OptionalListOfOrganizationId
    ): pass

    class GetMultipleFromOrganizationQuery(
        MaleoIdentityUserOrganizationGeneralSchemas.Expand,
        BaseClientParametersTransfers.GetPaginatedMultipleQuery,
        MaleoIdentityUserOrganizationGeneralSchemas.OptionalListOfUserId
    ): pass

    class GetMultipleQuery(
        MaleoIdentityUserOrganizationGeneralSchemas.Expand,
        BaseClientParametersTransfers.GetPaginatedMultipleQuery,
        MaleoIdentityUserOrganizationGeneralSchemas.OptionalListOfOrganizationId,
        MaleoIdentityUserOrganizationGeneralSchemas.OptionalListOfUserId
    ): pass
